nengolib\.signal\.LinearSystem
==============================

.. autoattribute:: nengolib.signal.s

.. autoattribute:: nengolib.signal.z

.. currentmodule:: nengolib.signal

.. autoclass:: LinearSystem

   **Subset of magic methods**

   .. autosummary::

      __len__
      __invert__
      __neg__
      __pow__
      __add__
      __sub__
      __mul__
      __div__
      __eq__
